============
Contributors
============

Development Lead
----------------

* Raphael Pierzina (`@hackebrot`_)

Pull Requests and Patches
-------------------------

* David Eyk (`@eykd`_)

Bug Reports and Suggestions
---------------------------

* Georgi Valkov (`@gvalkov`_)
* Jakub Kadlubiec (`@jakubka`_)
* Nicholas Chammas (`@nchammas`_)
* Michael Kennedy (`@mikeckennedy`_)
* `@sathlan`_

.. _`@eykd`: https://github.com/eykd
.. _`@gvalkov`: https://github.com/gvalkov
.. _`@hackebrot`: https://github.com/hackebrot
.. _`@jakubka`: https://github.com/jakubka
.. _`@nchammas`: https://github.com/nchammas
.. _`@sathlan`: https://github.com/sathlan
.. _`@mikeckennedy`: https://github.com/mikeckennedy
